==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-patch-editor/control-buttons/control-buttons-panel.js <==
import React from 'react';
import PropTypes from 'prop-types';
import {OverlayTrigger, Panel, Popover} from 'react-bootstrap';
import classNames from 'classnames';
import {localeMessages} from '../../../services/locale-service';
import {XlReactButton} from '../../../xl-react-buttons/xl-react-button/xl-react-button';
import {editorActions, REMOVE, REPLACE} from '../xl-react-widget-patch-editor-actions';
import './control-buttons-panel.less';

const ControlButtonsPanel = (props) => {
    const createPopover = (id) => <Popover
        className="control-buttons-popover"
        id={id}>
        {props.tooltipMessages[id] || localeMessages[id]}
    </Popover>;

    const {
        activeAction,
        handleModifyingPatch,
        handleRemovingPatch,
        isPanelActive
    } = props;

    const modifyPatchTooltip = createPopover('modifyPatchTooltip');
    const removePatchTooltip = createPopover('removePatchTooltip');

    const actionCssClassName = (action) => action === 'replace' ? 'edit' : action;

    const activeStyle = (currentAction) => ({active: activeAction === currentAction});

    const renderControl = (tooltip, action, handler) => <OverlayTrigger overlay={tooltip} placement="bottom">
        <span>
            <XlReactButton
                className={classNames('control-button', activeStyle(action))}
                disabled={!isPanelActive}
                excludeDefaultClassName={true}
                onClick={handler}>
                <i
                    aria-hidden="true"
                    className={classNames('xl-react-icon', actionCssClassName(action), activeStyle(action))}
                />
            </XlReactButton>
        </span>
    </OverlayTrigger>;

    return <Panel className="control-buttons-panel">
        <Panel.Body>
            {renderControl(modifyPatchTooltip, REPLACE, handleModifyingPatch)}
            {renderControl(removePatchTooltip, REMOVE, handleRemovingPatch)}
        </Panel.Body>
    </Panel>;
};

ControlButtonsPanel.propTypes = {
    activeAction: PropTypes.oneOf(editorActions),
    handleModifyingPatch: PropTypes.func.isRequired,
    handleRemovingPatch: PropTypes.func.isRequired,
    isPanelActive: PropTypes.bool.isRequired,
    tooltipMessages: PropTypes.object
};

ControlButtonsPanel.defaultProps = {tooltipMessages: {}};

export const XlControlButtonsPanel = React.memo(ControlButtonsPanel);

==> xl-react-components-0.21.9.tgz: package/app/xl-react-widget/xl-react-widget-patch-editor/control-buttons/control-buttons-panel.js <==
import React from 'react';
import PropTypes from 'prop-types';
import {OverlayTrigger, Panel, Popover} from 'react-bootstrap';
import classNames from 'classnames';
import {localeMessages} from '../../../services/locale-service';
import {XlReactButton} from '../../../xl-react-buttons/xl-react-button/xl-react-button';
import {editorActions, REMOVE, REPLACE} from '../xl-react-widget-patch-editor-actions';
import './control-buttons-panel.less';

const ControlButtonsPanel = (props) => {
    const createPopover = (id) => <Popover
        className="control-buttons-popover"
        id={id}>
        {props.tooltipMessages[id] || localeMessages[id]}
    </Popover>;

    const {
        activeAction,
        handleModifyingPatch,
        handleRemovingPatch,
        isPanelActive
    } = props;

    const modifyPatchTooltip = createPopover('modifyPatchTooltip');
    const removePatchTooltip = createPopover('removePatchTooltip');

    const actionCssClassName = (action) => action === 'replace' ? 'edit-icon' : `${action}-icon`;

    const activeStyle = (currentAction) => ({active: activeAction === currentAction});

    const renderControl = (tooltip, action, handler) => <OverlayTrigger overlay={tooltip} placement="bottom">
        <span>
            <XlReactButton
                className={classNames('control-button', activeStyle(action))}
                disabled={!isPanelActive}
                excludeDefaultClassName={true}
                onClick={handler}>
                <i
                    aria-hidden="true"
                    className={classNames('xl-icon', actionCssClassName(action), activeStyle(action))}
                />
            </XlReactButton>
        </span>
    </OverlayTrigger>;

    return <Panel className="control-buttons-panel">
        <Panel.Body>
            {renderControl(modifyPatchTooltip, REPLACE, handleModifyingPatch)}
            {renderControl(removePatchTooltip, REMOVE, handleRemovingPatch)}
        </Panel.Body>
    </Panel>;
};

ControlButtonsPanel.propTypes = {
    activeAction: PropTypes.oneOf(editorActions),
    handleModifyingPatch: PropTypes.func.isRequired,
    handleRemovingPatch: PropTypes.func.isRequired,
    isPanelActive: PropTypes.bool.isRequired,
    tooltipMessages: PropTypes.object
};

ControlButtonsPanel.defaultProps = {tooltipMessages: {}};

export const XlControlButtonsPanel = React.memo(ControlButtonsPanel);
